## dbt-adapters 1.16.4 - August 15, 2025

### Fixes

- Apply column quoting to unit tests ([#205](https://github.com/dbt-labs/dbt-adapters/issues/205))

### Dependencies

- upgrade protobuf to 6.0 ([#1259](https://github.com/dbt-labs/dbt-adapters/pull/1259))

### Contributors
- [@mpatek](https://github.com/mpatek) ([#205](https://github.com/dbt-labs/dbt-adapters/issues/205))
